function [negLlike, ww_bar] = logreg_negLlike(ww, X, yy)
%LOGREG_NEGLLIKE negative log-likelihood and gradients of logistic regression
%
%     [negLlike, ww_bar] = logreg_negLlike(ww, X, yy)
%
% There's no separate bias term. So X needs augmenting with a constant column to
% include a bias.
%
% Inputs:
%          ww Dx1 
%           X NxD 
%          yy Nx1 
%
% Outputs:
%    negLlike 1x1 
%      ww_bar Dx1 

% Iain Murray, November 2016

% Force targets to be +/- 1
yy = 2*(yy==1) - 1;

% forward computation of error
sigma = 1./(1 + exp(-yy.*(X*ww)));
negLlike = -sum(log(sigma));

% reverse computation of gradients
ww_bar = X'*(yy.*(sigma - 1));

